This is **Yet Another Form WIdget Library** (XHTML). There are plenty of 'em out 
in Python space.  

YAFOWIL offers html-form creation and modification at runtime. Its light-weight  
and provides an extensible, reusable set of form widgets, independent from any 
web-framework, but easy to use in your web-framework.

It's all just about rendering widgets and extracting the data returned from the 
browser per widget. It does not fight with storage. 

Yafowil widgets are a bit different: Its all just configuration. No 
subclassing needed any more; no specific schema-framework is necessary. 
 
Yafowil provides a factory where you can fetch your widgets instances from. 
Or you register your own.

Detailed Documentation
======================

If you're interested to dig deeper: The `detailed YAFOWIL documentation 
<http://packages.python.org/yafowil>`_ is available. Read it and learn how to 
create your example application with YAFOWIL forms in 15 minutes. 

Source Code
===========

The sources are in a GIT DVCS with its main branches at 
`github <http://github.com/bluedynamics/yafowil>`_.

We'd be happy to see many forks and pull-requests to make YAFOWIL even better.

Contributors
============

- Jens W. Klein <jens@bluedynamics.com>

- Robert Niederrreiter <rnix@squarewave.at>

- Attila Olah

- Christian Scholz aka MrTopf (initial discussion)
